
<style>
  .carousel-body {
    width: 100%;
    height: 400px;
    padding: 40px 100px 40px 100px;
    background-color: red;
    font-size: 40px;
  }
</style>

<div id="carouselExampleIndicators" class="carousel slide" data-ride="carousel">
  <ol class="carousel-indicators">
    <li data-target="#carouselExampleIndicators" data-slide-to="0" class="active"></li>
    <li data-target="#carouselExampleIndicators" data-slide-to="1"></li>
    <li data-target="#carouselExampleIndicators" data-slide-to="2"></li>
  </ol>
  <div class="carousel-inner">
    <div class="carousel-item active">
      <div class="carousel-body">{{ page.load('carousel1.rst').html }}</div>
    </div>
    <div class="carousel-item">
      <div class="carousel-body">{{ page.load('carousel2.rst').html }}</div>
    </div>
    <div class="carousel-item">
      <div class="carousel-body">{{ page.load('carousel3.rst').html }}</div>
    </div>
  </div>
  <a class="carousel-control-prev" href="#carouselExampleIndicators" role="button" data-slide="prev">
    <span class="carousel-control-prev-icon" aria-hidden="true"></span>
    <span class="sr-only">Previous</span>
  </a>
  <a class="carousel-control-next" href="#carouselExampleIndicators" role="button" data-slide="next">
    <span class="carousel-control-next-icon" aria-hidden="true"></span>
    <span class="sr-only">Next</span>
  </a>
</div>
